@@ -30,6 +30,13 @@ from typing import Any, Dict
 import pkg_resources
 
 from ..cli.load_arguments_from_dataclass import extract_fields_from_class
+from .diffusion.core import (
+    DiffusionDataArguments,
+    DiffusionForVisionTrainingPipeline,
+    DiffusionModelArguments,
+    DiffusionSavingArguments,
+    DiffusionTrainingArguments,
+)
 from .guacamol_baselines.core import GuacaMolDataArguments, GuacaMolSavingArguments
 from .guacamol_baselines.smiles_lstm.core import (
     GuacaMolLSTMModelArguments,
@@ -151,6 +158,11 @@ TRAINING_PIPELINE_ARGUMENTS_MAPPING = {
         RegressionTransformerDataArguments,
         RegressionTransformerModelArguments,
     ),
+    "diffusion-trainer": (
+        DiffusionTrainingArguments,
+        DiffusionDataArguments,
+        DiffusionModelArguments,
+    ),
     "gflownet-trainer": (
         GFlowNetPytorchLightningTrainingArguments,
         GFlowNetDataArguments,
@@ -168,6 +180,7 @@ TRAINING_PIPELINE_MAPPING = {
     "moses-organ-trainer": MosesOrganTrainingPipeline,
     "moses-vae-trainer": MosesVAETrainingPipeline,
     "regression-transformer-trainer": RegressionTransformerTrainingPipeline,
+    "diffusion-trainer": DiffusionForVisionTrainingPipeline,
     "gflownet-trainer": GFlowNetTrainingPipeline,
 }
 
@@ -181,6 +194,7 @@ TRAINING_PIPELINE_ARGUMENTS_FOR_MODEL_SAVING = {
     "moses-organ-trainer": MosesSavingArguments,
     "moses-vae-trainer": MosesSavingArguments,
     "regression-transformer-trainer": RegressionTransformerSavingArguments,
+    "diffusion-trainer": DiffusionSavingArguments,
     "gflownet-trainer": GFlowNetSavingArguments,
 }
 
